import React, { useImperativeHandle, useRef, forwardRef } from 'react'
import CodeMirror from '@uiw/react-codemirror'
import 'codemirror/keymap/sublime'
import 'codemirror/theme/monokai.css'
import PropTypes from 'prop-types'
import { useEffect } from 'react'

const JsonEditor = forwardRef(({ code }, ref) => {
  const jsonEditor = useRef()
  useImperativeHandle(ref, () => {
    return {
      jsonValue: jsonEditor.current,
    }
  })
  return (
    <CodeMirror
      ref={editor => (jsonEditor.current = editor)}
      value={JSON.stringify(JSON.parse(code), null, 2)}
      options={{
        theme: 'monokai',
        keyMap: 'sublime',
        mode: 'json',
      }}
    />
  )
})

export default JsonEditor

JsonEditor.propTypes = {
  code: PropTypes.string,
}
